==> cuery-0.1-bin.tar.gz: cuery-0.1/src/java/org/trix/cuery/value/AbstractCSSAngle.java <==
/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.value;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: AbstractCSSAngle.java,v 1.0 2005/08/09 20:09:47 Teletha Exp $
 */
public abstract class AbstractCSSAngle extends AbstractValue {

    /**
     * Create AbstractCSSAngle instance.
     * 
     * @param angle An angle.
     * @param previous A previous token.
     */
    public AbstractCSSAngle(String angle, Value previous) {
        super(previous);

        this.stringValue = angle;
        this.floatValue = Float.parseFloat(angle);
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getFloatValue()
     */
    public float getFloatValue() {
        return floatValue;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getStringValue()
     */
    public String getStringValue() {
        return stringValue;
    }

    /**
     * @see org.trix.cuery.value.AbstractValue#getCssText()
     */
    @Override
    public String getCssText() {
        return stringValue + getDimensionUnitText();
    }

}

==> cuery-0.2-bin.tar.gz: cuery-0.2/src/java/org/trix/cuery/value/AbstractCSSAngle.java <==
/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.value;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: AbstractCSSAngle.java,v 1.0 2005/08/09 20:09:47 Teletha Exp $
 */
public abstract class AbstractCSSAngle extends AbstractCSSValue implements CSSAngle {

    /**
     * Create AbstractCSSAngle instance.
     * 
     * @param angle An angle.
     * @param previous A previous token.
     */
    public AbstractCSSAngle(String angle, CSSValue previous) {
        super(previous);

        this.stringValue = angle;
        this.floatValue = Float.parseFloat(angle);
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getFloatValue()
     */
    public float getFloatValue() {
        return floatValue;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getStringValue()
     */
    public String getStringValue() {
        return stringValue;
    }

    /**
     * @see org.trix.cuery.value.AbstractCSSValue#getCssText()
     */
    public String getCssText() {
        return stringValue + getDimensionUnitText();
    }

}
